/**
 * Scroll Black Lives Matters names on a 8x32 WS2811/2 matrix.
 * 
 * Arduino Settings (Under the Tool menu):
 * Board: an Arduino compatible board
 * Port: refer to the documentation of your board
 * 
 */
#include <Adafruit_NeoMatrix.h>
#include <Adafruit_NeoPixel.h>
#include <Adafruit_GFX.h>
 
#define LED_COUNT 256 // 8x32 Matrix

// Set Up NeoPixels --------------------------------------
#define NEO_PIN 6     
#define NEO_WIDTH  32 // one panel
#define NEO_HEIGHT  8

Adafruit_NeoMatrix matrix(NEO_WIDTH, NEO_HEIGHT, NEO_PIN,
  NEO_MATRIX_TOP  + NEO_MATRIX_LEFT +
  NEO_MATRIX_COLUMNS + NEO_MATRIX_ZIGZAG,
  NEO_GRB         + NEO_KHZ800);

char          msg[21]     = {0};              // BLE 20 char limit + NUL
uint8_t       msgLen      = 0;                // Empty message
int           msgX          = matrix.width(); // Start off right edge
unsigned long prevFrameTime = 0L;             // For animation timing
#define FPS 20                                // Scrolling speed

int nameIdx = 0;
int numNames = 9;
char *names[] = { "Breonna Taylor",
                   "Charleena C Lyles", 
                   "Korryn Gaines",
                   "Sandra Bland",
                   "Alexia Christian", 
                   "Mya Hall",
                   "Meagan Hockaday",
                   "Janisha Fonville",
                   "Natasha McKenna"
                  };

void setup() {
  matrix.begin();
  matrix.setTextWrap(false);   // Allow scrolling off left
  matrix.setTextColor(matrix.Color(255, 0, 0)); // red
  // 0 (off) to 255 (max brightness)
  matrix.setBrightness(90);    // Batteries have limited sauce

  strcpy(msg, names[nameIdx]);  // Default Starting Message
  msgLen = sizeof(msg);
}

void loop() {
  unsigned long t = millis(); // Current elapsed time, milliseconds.
  // millis() comparisons are used rather than delay() so that animation
  // speed is consistent regardless of message length & other factors.
  
  // Handle scrolling
  if ((t - prevFrameTime) >= (1000L / FPS)) { 
    matrix.fillScreen(0);
    matrix.setCursor(msgX, 0);
    matrix.print(msg);
    if (--msgX < (msgLen * -5)) {
      //Serial.println(F("resetting scrolling"));
      msgX = matrix.width(); // We must repeat!
      
      nameIdx = nameIdx +1;
      if (nameIdx >= numNames) {
        //Serial.println(F("back to the begining"));
        nameIdx = 0;
      }
      strcpy(msg, names[nameIdx]);  // Default Starting Message
      msgLen = sizeof(msg);
    }
    matrix.show();
    prevFrameTime = t;
  }
}
